Home
last modified time | relevance | path

Searched refs:dot (Results 1 – 25 of 346) sorted by relevance

12345678910>>...14

/freebsd-12.1/contrib/libpcap/
H A DCREDITS9 Michael Richardson <mcr at sandelman dot ottawa dot on dot ca>
17 Alexander 'Leo' Bergolth <Leo dot Bergolth at wu-wien dot ac dot at>
18 Alexey Kuznetsov <kuznet at ms2 dot inr dot ac dot ru>
27 Armando L. Caro Jr. <acaro at mail dot eecis dot udel dot edu>
45 David Ward <david dot ward at ll dot mit dot edu>
55 Erik de Castro Lopo <erik dot de dot castro dot lopo at sensorynetworks dot com>
69 Gregor Maier <gregor at net dot in dot tum dot de>
94 Juergen Schoenwaelder <schoenw at ibr dot cs dot tu-bs dot de>
95 Julien Moutinho <julm at savines dot alpes dot fr dot eu dot org>
97 Kazushi Sugyo <sugyo at pb dot jp dot nec dot com>
[all …]
/freebsd-12.1/contrib/tcpdump/
H A DCREDITS9 Michael Richardson <mcr at sandelman dot ottawa dot on dot ca>
20 Andrea Bittau <a dot bittau at cs dot ucl dot ac dot uk>
31 Armando L. Caro Jr. <acaro at mail dot eecis dot udel dot edu>
36 Ben Smithurst <ben at scientia dot demon dot co dot uk>
59 Darren Reed <darrenr at reed dot wattle dot id dot au>
80 Gerrit Renker <gerrit at erg dot abdn dot ac dot uk>
119 Kazushi Sugyo <sugyo at pb dot jp dot nec dot com>
121 Ken Hornstein <kenh at cmf dot nrl dot navy dot mil>
134 Maciej W. Rozycki <macro at ds2 dot pg dot gda dot pl>
142 Marshall Rose <mrose at dbc dot mtview dot ca dot us>
[all …]
/freebsd-12.1/share/skel/
H A DMakefile4 FILES= dot.cshrc dot.login dot.login_conf dot.mailrc dot.profile \
5 dot.shrc dot.mail_aliases
/freebsd-12.1/usr.bin/mail/
H A Dcmd1.c76 if (dot != &message[n-1]) in headers()
77 dot = mp; in headers()
159 dot = &message[*ip - 1]; in from()
331 dot = mp; in type1()
386 dot = mp; in top()
414 dot = &message[*ip-1]; in stouch()
415 dot->m_flag |= MTOUCH; in stouch()
416 dot->m_flag &= ~MPRESERVE; in stouch()
431 dot = &message[*ip-1]; in mboxit()
433 dot->m_flag &= ~MPRESERVE; in mboxit()
[all …]
H A Dcmd2.c72 mdot = dot - &message[0] + 1; in next()
88 dot = mp; in next()
120 dot = mp; in next()
126 list[0] = dot - &message[0] + 1; in next()
287 lastdot = dot - &message[0] + 1; in deltype()
289 list[0] = dot - &message[0] + 1; in deltype()
291 touch(dot); in deltype()
321 dot = &message[last-1]; in delm()
324 dot = &message[last-1]; in delm()
328 dot = &message[0]; in delm()
[all …]
/freebsd-12.1/usr.bin/caesar/
H A Dcaesar.c81 int ch, dot, i, nread, winnerdot = 0; in main() local
119 dot = 0; in main()
121 dot += obs[i] * stdf[(i + try) % 26]; in main()
124 winnerdot = dot; in main()
125 if (dot > winnerdot) { in main()
128 winnerdot = dot; in main()
/freebsd-12.1/bin/date/
H A Ddate.c284 const char *dot, *t; in setthetime() local
303 for (t = p, dot = NULL; *t; ++t) { in setthetime()
306 if (*t == '.' && dot == NULL) { in setthetime()
307 dot = t; in setthetime()
313 if (dot != NULL) { /* .ss */ in setthetime()
314 dot++; /* *dot++ = '\0'; */ in setthetime()
315 if (strlen(dot) != 2) in setthetime()
317 lt->tm_sec = ATOI2(dot); in setthetime()
325 switch (strlen(p) - ((dot != NULL) ? 3 : 0)) { in setthetime()
/freebsd-12.1/share/misc/
H A DMakefile8 FILES= ascii birthtoken bsd-family-tree committers-doc.dot committers-ports.dot \
9 committers-src.dot flowers init.ee \
12 organization.dot
/freebsd-12.1/bin/pax/
H A Dsel_subs.c334 int dot = 0; in trng_add() local
356 dot = 0; in trng_add()
363 if ((*stpt == '.') && (!dot)) { in trng_add()
364 ++dot; in trng_add()
541 char *dot = NULL; in str_sec() local
544 if ((dot = strchr(str, '.')) != NULL) { in str_sec()
548 *dot++ = '\0'; in str_sec()
549 if (strlen(dot) != 2) in str_sec()
551 if ((lt->tm_sec = ATOI2(dot)) > 61) in str_sec()
/freebsd-12.1/contrib/bmake/
H A Ddir.c407 if (dot != NULL) { in Dir_InitDot()
417 if (dot == NULL) { in Dir_InitDot()
426 dot->refCount += 1; in Dir_InitDot()
450 dot->refCount -= 1; in Dir_End()
453 Dir_Destroy(dot); in Dir_End()
486 if (dot) in Dir_SetPATH()
502 if (dot) in Dir_SetPATH()
984 if (p != dot) { in DirLookupSubdir()
1089 dot->hits += 1; in DirFindDot()
1256 if (dot) { in Dir_FindFile()
[all …]
/freebsd-12.1/contrib/amd/amq/
H A Dpawd.c92 char *to, *ch, *hes_name, *dot; in hack_name() local
135 dot = hes_name; in hack_name()
136 while (*dot && *dot != '.') dot++; in hack_name()
137 *dot = '\0'; in hack_name()
/freebsd-12.1/contrib/openpam/lib/libpam/
H A Dopenpam_dynamic.c185 int dot, len; in openpam_dynamic() local
233 *path, modname, &dot); in openpam_dynamic()
236 *path, modname, &dot, LIB_MAJ); in openpam_dynamic()
239 *path, modname, PAM_SOEXT, &dot, LIB_MAJ); in openpam_dynamic()
248 if (errno == ENOENT && modpath[dot] != '\0') { in openpam_dynamic()
250 modpath[dot] = '\0'; in openpam_dynamic()
/freebsd-12.1/contrib/netbsd-tests/modules/k_helper3/
H A Dk_helper3.c61 char filename[MAXPATHLEN], *propsstr, *shortname, *dot; in load() local
94 dot = strrchr(shortname, '.'); in load()
95 if (dot) in load()
96 *dot = 0; in load()
/freebsd-12.1/crypto/heimdal/appl/ftp/ftp/
H A Druserpass.c77 char *dot; in guess_domain() local
83 dot = strchr (hostname_str, '.'); in guess_domain()
84 if (dot != NULL) in guess_domain()
85 return dot + 1; in guess_domain()
100 dot = strchr (hostname_str, '.'); in guess_domain()
101 if (dot != NULL) in guess_domain()
102 return dot + 1; in guess_domain()
/freebsd-12.1/contrib/llvm/tools/clang/include/clang/Basic/
H A DBuiltinsAMDGPU.def138 TARGET_BUILTIN(__builtin_amdgcn_fdot2, "fV2hV2hfIb", "nc", "dot-insts")
139 TARGET_BUILTIN(__builtin_amdgcn_sdot2, "SiV2SsV2SsSiIb", "nc", "dot-insts")
140 TARGET_BUILTIN(__builtin_amdgcn_udot2, "UiV2UsV2UsUiIb", "nc", "dot-insts")
141 TARGET_BUILTIN(__builtin_amdgcn_sdot4, "SiSiSiSiIb", "nc", "dot-insts")
142 TARGET_BUILTIN(__builtin_amdgcn_udot4, "UiUiUiUiIb", "nc", "dot-insts")
143 TARGET_BUILTIN(__builtin_amdgcn_sdot8, "SiSiSiSiIb", "nc", "dot-insts")
144 TARGET_BUILTIN(__builtin_amdgcn_udot8, "UiUiUiUiIb", "nc", "dot-insts")
/freebsd-12.1/contrib/amd/amd/
H A Dget_args.c238 char *dot = strchr(optarg, '.'); in get_args() local
240 if (dot) in get_args()
241 *dot = '\0'; in get_args()
246 if (dot) { in get_args()
248 gopt.amfs_auto_retrans[i] = atoi(dot + 1); in get_args()
249 *dot = '.'; in get_args()
/freebsd-12.1/usr.sbin/bsdconfig/dot/
H A DUSAGE36 View dot(1) language output describing bsdconfig(8) layout/make-up:
40 Render dot(1) output in SVG format (displays in most modern browsers):
42 bsdconfig @PROGRAM_NAME@ | dot -Tsvg -o bsdconfig.svg
78 Render dot(1) output as PostScript print output consisting of multiple
82 bsdconfig @PROGRAM_NAME@ | dot -Teps -o bsdconfig.eps
91 Render dot(1) output as PostScript scaled to fit on a poster consisting
94 bsdconfig @PROGRAM_NAME@ | dot -Teps -o bsdconfig.eps
H A DMakefile5 FILESDIR= ${LIBEXECDIR}/bsdconfig/dot
9 SCRIPTS= dot
/freebsd-12.1/libexec/rtld-elf/
H A Drtld_printf.c132 int base, lflag, qflag, tmp, width, ladjust, sharpflag, neg, sign, dot; in kvprintf() local
156 sign = 0; dot = 0; dwidth = 0; upper = 0; in kvprintf()
160 dot = 1; in kvprintf()
175 if (!dot) { in kvprintf()
186 if (!dot) { in kvprintf()
199 if (dot) in kvprintf()
303 if (!dot) in kvprintf()
/freebsd-12.1/usr.bin/jot/
H A Djot.c417 int dot, hash, space, sign, numbers = 0; in getformat() local
448 dot = hash = space = sign = numbers = 0; in getformat()
453 } else if ((*p == '#' && !(numbers|dot|sign|space| in getformat()
455 (*p == ' ' && !(numbers|dot|space++)) || in getformat()
456 ((*p == '+' || *p == '-') && !(numbers|dot|sign++)) in getformat()
457 || (*p == '.' && !(dot++))) in getformat()
/freebsd-12.1/stand/libsa/
H A Dprintf.c258 int base, lflag, qflag, tmp, width, ladjust, sharpflag, neg, sign, dot; in kvprintf() local
286 sign = 0; dot = 0; dwidth = 0; upper = 0; in kvprintf()
290 dot = 1; in kvprintf()
305 if (!dot) { in kvprintf()
316 if (!dot) { in kvprintf()
328 if (dot) in kvprintf()
432 if (!dot) in kvprintf()
/freebsd-12.1/usr.sbin/tcpdrop/
H A Dtcpdrop.c141 char *dot, *colon; in findport() local
144 dot = strrchr(arg, '.'); in findport()
146 if (dot == NULL) in findport()
149 return (dot); in findport()
150 if (dot < colon) in findport()
153 return (dot); in findport()
/freebsd-12.1/contrib/libc++/
H A DCREDITS.TXT28 E: vanboxem dot ruben at gmail dot com
32 E: theraven at theravensnest dot org
92 E: aep at exys dot org
126 E: r1mikey at gmail dot com
132 E: klaas at klaasgaaf dot nl
/freebsd-12.1/crypto/heimdal/lib/roken/
H A Dgetnameinfo.c58 char *dot = strchr (host, '.'); in doit() local
59 if (dot != NULL) in doit()
60 *dot = '\0'; in doit()
/freebsd-12.1/sys/cddl/dev/dtrace/
H A Ddtrace_debug.c237 int base, lflag, qflag, tmp, width, ladjust, sharpflag, neg, sign, dot; in dtrace_debug_vprintf() local
261 sign = 0; dot = 0; dwidth = 0; upper = 0; in dtrace_debug_vprintf()
265 dot = 1; in dtrace_debug_vprintf()
280 if (!dot) { in dtrace_debug_vprintf()
291 if (!dot) { in dtrace_debug_vprintf()
303 if (dot) in dtrace_debug_vprintf()
407 if (!dot) in dtrace_debug_vprintf()

12345678910>>...14